/**
 * Transform: delete src/generated/
 *
 * The generated directory is 100% CLI-managed in v1.  In v2 it is gone.
 */
import { rmSync } from 'node:fs';
export function deleteGeneratedDir(generatedDir) {
    rmSync(generatedDir, { recursive: true, force: true });
}
//# sourceMappingURL=generated.js.map